"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StartupContribution = void 0;
const tslib_1 = require("tslib");
/* eslint-disable no-console */
const di_1 = require("@opensumi/di");
const ide_core_browser_1 = require("@opensumi/ide-core-browser");
const layout_1 = require("@opensumi/ide-core-browser/lib/layout");
const next_1 = require("@opensumi/ide-core-browser/lib/menu/next");
const services_1 = require("@opensumi/ide-core-browser/lib/services");
const ide_core_common_1 = require("@opensumi/ide-core-common");
const di_helper_1 = require("@opensumi/ide-core-common/lib/di-helper");
const browser_1 = require("@opensumi/ide-editor/lib/browser");
const output_service_1 = require("@opensumi/ide-output/lib/browser/output.service");
const editor_bottom_example_1 = require("./editor-bottom-example");
const editor_top_example_1 = require("./editor-top-example");
const exmaple_popover_1 = require("./exmaple-popover");
let StartupContribution = class StartupContribution {
    onStart() { }
    registerEditorComponent(registry) {
        registry.registerEditorSideWidget({
            id: 'example-bottom',
            side: 'bottom',
            component: editor_bottom_example_1.ExampleEditorBottomWidget,
            displaysOnResource: (r) => r.uri.scheme === ide_core_common_1.Schemes.file,
        });
        registry.registerEditorSideWidget({
            id: 'example-top',
            side: 'top',
            component: editor_top_example_1.ExampleEditorTopWidget,
            displaysOnResource: (r) => r.uri.scheme === ide_core_common_1.Schemes.file,
        });
    }
    registerComponent(registry) { }
    registerCommands(commands) {
        commands.registerCommand({
            id: 'gitCommitAndPush',
        }, {
            execute: async (provider, commitMsg) => {
                // 强依赖了 git 插件的命令
                const mergeChanges = provider.groups.elements.filter((n) => n.id === 'merge');
                if (mergeChanges.length > 0) {
                    // console.log('有冲突尚未解决，请先解决');
                    return;
                }
                await this.commandService.executeCommand('git.stageAll', provider);
                await this.commandService.executeCommand('git.commit', provider);
                await this.commandService.executeCommand('git.push', provider);
            },
        });
    }
    registerKeybindings(keybindings) { }
    registerToolbarActions(registry) {
        registry.addLocation('menu-left');
        registry.registerToolbarActionGroup({
            id: 'test-compact',
            compact: true,
            preferredLocation: 'menu-right',
        });
        for (let i = 0; i < 6; i++) {
            registry.registerToolbarAction({
                id: 'test-' + i,
                description: 'test-' + i + '按钮',
                component: (0, ide_core_browser_1.createToolbarActionBtn)({
                    id: 'test-' + i,
                    title: 'test-' + i,
                    iconClass: (0, ide_core_browser_1.getIcon)('open'),
                    defaultStyle: {
                        btnStyle: i > 3 ? 'button' : 'inline',
                        background: i > 4 ? 'red' : undefined,
                    },
                    popoverComponent: exmaple_popover_1.ExamplePopover,
                    popoverStyle: {
                        noContainerStyle: i % 2 === 0,
                    },
                    delegate: (d) => {
                        d === null || d === void 0 ? void 0 : d.onClick(() => {
                            console.log('test ' + i + ' clicked');
                            d.showPopOver({
                                horizontalOffset: i * 10,
                            });
                        });
                    },
                }),
                neverCollapse: i > 4,
                preferredPosition: {
                    location: 'menu-right',
                    group: i === 1 || i === 2 || i === 3 ? 'test-compact' : undefined,
                },
            });
        }
        for (let i = 7; i < 10; i++) {
            registry.registerToolbarAction({
                id: 'test-' + i,
                description: 'test-' + i + '按钮',
                component: (0, ide_core_browser_1.createToolbarActionBtn)({
                    id: 'test-' + i,
                    title: 'test-' + i,
                    iconClass: (0, ide_core_browser_1.getIcon)('open'),
                    defaultStyle: {
                        btnStyle: i > 3 ? 'button' : 'inline',
                    },
                    delegate: (d) => {
                        d === null || d === void 0 ? void 0 : d.onClick(() => {
                            console.log('test ' + i + ' clicked');
                        });
                    },
                }),
                preferredPosition: {
                    location: 'menu-left',
                },
            });
        }
        registry.registerToolbarAction({
            id: 'test-select-1',
            description: '选项框1',
            weight: 11,
            component: (0, ide_core_browser_1.createToolbarActionSelect)({
                name: 'test-1',
                delegate: (d) => {
                    d === null || d === void 0 ? void 0 : d.onSelect((value) => {
                        console.log('value ' + value + ' selected');
                    });
                },
                options: [
                    {
                        label: '选项a',
                        value: 'a',
                    },
                    {
                        label: '选项b',
                        value: 'b',
                    },
                    {
                        label: '选项c',
                        value: 'c',
                    },
                ],
                defaultValue: 'b',
            }),
        });
        registry.registerToolbarAction({
            id: 'test-select-2',
            weight: 11,
            description: '选项框2',
            component: (0, ide_core_browser_1.createToolbarActionSelect)({
                name: 'test-2',
                delegate: (d) => {
                    d === null || d === void 0 ? void 0 : d.onSelect((value) => {
                        console.log('value ' + value + ' selected');
                    });
                },
                options: [
                    {
                        groupName: 'TestGroup1',
                        options: [
                            {
                                label: '选项a',
                                value: 'a',
                            },
                            {
                                label: '选项b',
                                value: 'b',
                            },
                            {
                                label: '选项c',
                                value: 'c',
                            },
                        ],
                    },
                    {
                        iconClass: (0, ide_core_browser_1.getIcon)('open'),
                        groupName: 'TestGroup2',
                        options: [
                            {
                                label: '选项aa',
                                value: 'ab',
                                iconClass: (0, ide_core_browser_1.getIcon)('open'),
                            },
                            {
                                label: '选项bb',
                                value: 'bb',
                                iconClass: (0, ide_core_browser_1.getIcon)('open'),
                            },
                            {
                                label: '选项cc',
                                value: 'cc',
                                iconClass: (0, ide_core_browser_1.getIcon)('open'),
                            },
                        ],
                    },
                ],
                defaultValue: 'cc',
            }),
        });
    }
    registerMenus(menuRegistry) {
        menuRegistry.registerMenuItem(next_1.MenuId.SCMInput, {
            command: {
                id: 'gitCommitAndPush',
                label: '提交并推送',
            },
            group: 'navigation',
            type: 'primary',
        });
        menuRegistry.registerMenuItem(next_1.MenuId.SCMInput, {
            command: {
                id: 'editor.action.quickCommand',
                label: '打开 quick open',
            },
            group: 'navigation',
            type: 'primary',
        });
    }
};
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_common_1.IEventBus),
    tslib_1.__metadata("design:type", Object)
], StartupContribution.prototype, "eventBus", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(services_1.IStatusBarService),
    tslib_1.__metadata("design:type", Object)
], StartupContribution.prototype, "statusBar", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(output_service_1.OutputService),
    tslib_1.__metadata("design:type", output_service_1.OutputService)
], StartupContribution.prototype, "outputService", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(),
    tslib_1.__metadata("design:type", ide_core_browser_1.Logger)
], StartupContribution.prototype, "logger", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_browser_1.IToolbarRegistry),
    tslib_1.__metadata("design:type", Object)
], StartupContribution.prototype, "toolbarRegistry", void 0);
tslib_1.__decorate([
    (0, di_1.Autowired)(ide_core_common_1.CommandService),
    tslib_1.__metadata("design:type", Object)
], StartupContribution.prototype, "commandService", void 0);
StartupContribution = tslib_1.__decorate([
    (0, di_helper_1.Domain)(ide_core_browser_1.ClientAppContribution, ide_core_common_1.CommandContribution, ide_core_browser_1.KeybindingContribution, layout_1.ComponentContribution, ide_core_browser_1.ToolBarActionContribution, next_1.MenuContribution, browser_1.BrowserEditorContribution)
], StartupContribution);
exports.StartupContribution = StartupContribution;
//# sourceMappingURL=startup.contribution.js.map